@@ -19,7 +19,7 @@ pub trait ParseMention: private::Sealed {
     /// Leading sigil(s) of the mention after the leading arrow (`<`).
     ///
     /// In a channel mention, the sigil is `#`. In the case of a user mention,
-    /// the sigil may be either `@` or `@!`.
+    /// the sigil would be `@`.
     const SIGILS: &'static [&'static str];
 
     /// Parse a mention out of a buffer.
@@ -102,7 +102,7 @@ impl ParseMention for MentionType {
     /// Sigils for any type of mention.
     ///
     /// Contains all of the sigils of every other type of mention.
-    const SIGILS: &'static [&'static str] = &["#", ":", "@&", "@!", "@", "t:"];
+    const SIGILS: &'static [&'static str] = &["#", ":", "@&", "@", "t:"];
 
     /// Parse a mention from a string slice.
     ///
@@ -193,10 +193,8 @@ impl ParseMention for Timestamp {
 }
 
 impl ParseMention for Id<UserMarker> {
-    /// Sigils for User ID mentions.
-    ///
-    /// Unlike other IDs, user IDs have two possible sigils: `@!` and `@`.
-    const SIGILS: &'static [&'static str] = &["@!", "@"];
+    /// Sigil for User ID mentions.
+    const SIGILS: &'static [&'static str] = &["@"];
 
     fn parse(buf: &str) -> Result<Self, ParseMentionError<'_>>
     where
@@ -380,9 +378,9 @@ mod tests {
     fn test_sigils() {
         assert_eq!(&["#"], Id::<ChannelMarker>::SIGILS);
         assert_eq!(&[":"], Id::<EmojiMarker>::SIGILS);
-        assert_eq!(&["#", ":", "@&", "@!", "@", "t:"], MentionType::SIGILS);
+        assert_eq!(&["#", ":", "@&", "@", "t:"], MentionType::SIGILS);
         assert_eq!(&["@&"], Id::<RoleMarker>::SIGILS);
-        assert_eq!(&["@!", "@"], Id::<UserMarker>::SIGILS);
+        assert_eq!(&["@"], Id::<UserMarker>::SIGILS);
     }
 
     #[test]
@@ -432,7 +430,7 @@ mod tests {
         );
         assert_eq!(
             &ParseMentionErrorType::Sigil {
-                expected: &["#", ":", "@&", "@!", "@", "t:"],
+                expected: &["#", ":", "@&", "@", "t:"],
                 found: Some(';'),
             },
             MentionType::parse("<;123>").unwrap_err().kind(),
